{#-
    The search page template modified from theme/basic/search.html
-#}
{% extends "page.html" %}

{%- block regular_scripts -%}
{{ super() }}
<script src="{{ pathto('_static/searchtools.js', 1) }}"></script>
<script src="{{ pathto('_static/language_data.js', 1) }}"></script>
{%- endblock regular_scripts-%}

{%- block htmltitle -%}
<title>{{ _("Search") }} - {{ docstitle }}</title>
{%- endblock htmltitle -%}

{% block scripts -%}
{{ super() }}
<script src="{{ pathto('searchindex.js', 1) }}"></script>
{%- endblock scripts %}

{% block content %}
<h1 id="search-documentation">{{ _('Search') }}</h1>
{% block scriptwarning %}
  <noscript>
  <div class="admonition warning">
  <p>
    {% trans %}Please activate JavaScript to enable the search
    functionality.{% endtrans %}
  </p>
  </div>
  </noscript>
{% endblock %}
{% block searchtext %}
  <p>
    {% trans %}Searching for multiple words only shows matches that contain
    all words.{% endtrans %}
  </p>
  <p>
    {% trans %}Note also that you can also call "search_src(...)"
    in Sage to search Sage's source code.{% endtrans %}
  </p>
{% endblock %}
{% block searchbox %}
  <form action="" method="get">
    <input type="text" name="q" aria-labelledby="search-documentation" value="" autocomplete="off" autocorrect="off" autocapitalize="off" spellcheck="false"/>
    <input type="submit" value="{{ _('search') }}" />
    <span id="search-progress" style="padding-left: 10px"></span>
  </form>
{% endblock %}
{% block searchresults %}
  {% if search_performed %}
    <h2>{{ _('Search Results') }}</h2>
    {% if not search_results %}
      <p>{{ _('Your search did not match any documents.') }}</p>
    {% endif %}
  {% endif %}
  <div id="search-results">
  {% if search_results %}
    <ul>
    {% for href, caption, context in search_results %}
      <li><a href="{{ pathto(item.href) }}">{{ caption }}</a>
        <div class="context">{{ context|e }}</div>
      </li>
    {% endfor %}
    </ul>
  {% endif %}
  </div>
{% endblock %}
{% endblock %}

